{% for row_id, row_values in rows_values %}
  <tr class="csv-table-row" data-row-id="{{ row_id }}">
    <td>{{ row_id }}</td>
    {% for value in row_values %}
      <td>{{ value }}</td>
    {% endfor %}
  </tr>
{% endfor %}
