<!doctype html>
<html>
  <head>
    <title>racks@tabs</title>
    <link rel="stylesheet" href="https://cdn.rawgit.com/kimeiga/bahunya/css/bahunya-0.1.3.css" />
    <link rel="stylesheet" href="{{ app_css_url }}" />
    <link rel="shortcut icon" href="{{ favicon_url }}">
    <script type="text/javascript" src="{{ app_js_url }}"></script>
  </head>
  <body>
    <h1>racks on '{{ csv_path }}' tabs</h1>
    <table id="csv-table">
      <tr>
        <th class="csv-table-header">row id</th>
        {% for header in table_headers %}
          <th class="csv-table-header">{{ header }}</th>
        {% endfor %}
      </tr>
    </table>
    <p id="post-table-p">loading rows...</>
  </body>
</html>
